@@ -88,19 +88,19 @@ umvn <- function(data) {
     
     datemp <- cbind(data, jitter(data)); colnames(datemp) <- c(colnames(data), 'jitd')
     
-    res1 <- MVN::mvn(data=datemp, univariateTest = "SW")
+    res1 <- MVN::mvn(data=datemp, univariate_test = "SW")
     
-    Shapiro_Wilk <- res1$"univariateNormality"[1,]
+    Shapiro_Wilk <- res1$"univariate_normality"[1,]
     
-    descriptives <- res1$"Descriptives"
+    descriptives <- res1$"descriptives"
     
-    Shapiro_Francia <- MVN::mvn(data=datemp, univariateTest = "SF")$"univariateNormality"[1,]
+    Shapiro_Francia <- MVN::mvn(data=datemp, univariate_test = "SF")$"univariate_normality"[1,]
     
-    Anderson_Darling <- MVN::mvn(data=datemp, univariateTest = "AD", desc = FALSE)$"univariateNormality"[1,]
+    Anderson_Darling <- MVN::mvn(data=datemp, univariate_test = "AD", desc = FALSE)$"univariate_normality"[1,]
     
-    Cramer_von_Mises <- MVN::mvn(data=datemp, univariateTest = "CVM", desc = FALSE)$"univariateNormality"[1,]
+    Cramer_von_Mises <- MVN::mvn(data=datemp, univariate_test = "CVM", desc = FALSE)$"univariate_normality"[1,]
     
-    Lilliefors <- MVN::mvn(data=datemp, univariateTest = "Lillie", desc = FALSE)$"univariateNormality"[1,]
+    Lilliefors <- MVN::mvn(data=datemp, univariate_test = "Lillie", desc = FALSE)$"univariate_normality"[1,]
     
     univariate_tests <- rbind(Shapiro_Wilk, Shapiro_Francia, Anderson_Darling, Cramer_von_Mises, Lilliefors)
     
@@ -109,37 +109,37 @@ umvn <- function(data) {
   
   if (ncol(data) > 1) {
     
-    res1 <- MVN::mvn(data=data, mvnTest = "mardia", univariateTest = "SW")
+    res1 <- MVN::mvn(data=data, mvn_test = "mardia", univariate_test = "SW")
     
-    descriptives <- res1$"Descriptives"
+    descriptives <- res1$"descriptives"
     
-    Shapiro_Wilk <- res1$"univariateNormality"
+    Shapiro_Wilk <- res1$"univariate_normality"
     
-    Mardia       <- res1$"multivariateNormality"[1:2,]
+    Mardia       <- res1$"multivariate_normality"[1:2,]
     
     
-    res2 <- MVN::mvn(data = data, mvnTest = "hz", univariateTest = "SF",  desc = FALSE)
+    res2 <- MVN::mvn(data = data, mvn_test = "hz", univariate_test = "SF",  desc = FALSE)
     
-    Shapiro_Francia <- res2$"univariateNormality"
+    Shapiro_Francia <- res2$"univariate_normality"
     
-    Henze_Zirkler   <- res2$"multivariateNormality"
+    Henze_Zirkler   <- res2$"multivariate_normality"
     
     
-    res3 <- MVN::mvn(data = data, mvnTest = "royston", univariateTest = "AD",  desc = FALSE)
+    res3 <- MVN::mvn(data = data, mvn_test = "royston", univariate_test = "AD",  desc = FALSE)
     
-    Anderson_Darling <-res3$"univariateNormality"
+    Anderson_Darling <-res3$"univariate_normality"
     
-    Royston <- res3$"multivariateNormality"
+    Royston <- res3$"multivariate_normality"
     
     
-    res4 <- MVN::mvn(data = data, mvnTest = "dh", univariateTest = "CVM",  desc = FALSE)    
+    res4 <- MVN::mvn(data = data, mvn_test = "doornik_hansen", univariate_test = "CVM",  desc = FALSE)    
     
-    Cramer_von_Mises <- res4$"univariateNormality"
+    Cramer_von_Mises <- res4$"univariate_normality"
     
-    Doornik_Hansen <- res4$"multivariateNormality"
+    Doornik_Hansen <- res4$"multivariate_normality"
     
     
-    Lilliefors <- MVN::mvn(data=data, univariateTest = "Lillie", desc = FALSE)$"univariateNormality"
+    Lilliefors <- MVN::mvn(data=data, univariate_test = "Lillie", desc = FALSE)$"univariate_normality"
     
     
     univariate_tests <- list(Shapiro_Wilk, Shapiro_Francia, Anderson_Darling, Cramer_von_Mises, Lilliefors)
@@ -170,14 +170,15 @@ umvn <- function(data) {
   kurtosisZ  <- descriptives$Kurtosis / kurtosisSE	
   kurtosisP  <- pnorm(abs(kurtosisZ), lower.tail=FALSE) * 2     # 2-tailed sig test
   
-  descriptives <- cbind(descriptives[,c(1:6,9)], skewZ, skewP, descriptives$Kurtosis, kurtosisZ, kurtosisP)
-  colnames(descriptives)[1] <- 'N'
-  colnames(descriptives)[8:12] <- c('z (Skew)','p (Skew)','Kurtosis','z (Kurtosis)','p (Kurtosis)')
+  descriptives2 <- cbind(descriptives[,c(2:6,9)], skewZ, skewP, descriptives$Kurtosis, kurtosisZ, kurtosisP)
+  rownames(descriptives2) <- descriptives[,1]
+  # colnames(descriptives2)[1] <- 'N'
+  colnames(descriptives2)[7:11] <- c('z (Skew)','p (Skew)','Kurtosis','z (Kurtosis)','p (Kurtosis)')
   
   if (ncol(data) == 1) descriptives <- descriptives[1,]
   
   output <- list(  
-    descriptives = descriptives,
+    descriptives = descriptives2,
     univariate_tests = univariate_tests,
     multivariate_tests = multivariate_tests
   )
